;
; "Juicy Fonts" User Function Demo - v1.0
;
; Copyright (c) Chris Chadwick 2006.
;

	Graphics 1024,768,32
	SetBuffer BackBuffer()

	; Include the Juicy Fonts library of user functions.
	Include "LIB_juicy_fonts.bb"

	Const MARGIN% = 32

	; FPS timing.
	Global frame_count%
	Global fps%
	Global slowest_fps%
	Global fps_timeout%
	Global frame_time%
	Global slowest_frame%
	Global frame_start%

	fps_timer = CreateTimer(60)

	Global info_on = False	
	frame_lock = True
		
	; Load some juicy fonts.
	Global big_font		= jf_load_font("demo_big.png")
	Global small_font	= jf_load_font("..\Fonts\PressStartK.png")
	Global debug_font	= jf_load_font("debug.png")

	; Load background tile.
	star_tile = LoadImage("star_tile.png")

	; Define the text strings.
	help$		= "Press: F1 for info - F2 to toggle frame lock - ESCAPE to exit"
	juicy$	= Chr$(34) + "Juicy Fonts" + Chr$(34) + " Bitmap Font Creation Utility"
	blurb$	= "Juicy Fonts makes it easy to create attractive, bitmap fonts for use in your "
	blurb$	= blurb$ + "Blitz3D and BlitzPlus games and applications. Exported fonts can be "
	blurb$	= blurb$ + "further enhanced using all the groovy tools and special effects of "
	blurb$	= blurb$ + "your favourite image editor. Displaying your fonts in your programs is "
	blurb$	= blurb$ + "easy, too. The provided Juicy Fonts User Function Library takes care "
	blurb$	= blurb$ + "of all that for you. It's a snap!"
	
	; Create the static text objects.
	help_text		= jf_create_text(small_font,400,MARGIN,help$,1)
	blurb_text	= jf_create_text(small_font,400,600-MARGIN,blurb$,1,2,650)

	; Measure help & blurb text to calculate the Y coord of the juicy text.
	jf_measure_text(small_font,blurb$,650)
	blurb_height = jf_text_height
	jf_measure_text(small_font,help$)
	help_height = jf_text_height
	gap = (600 - (MARGIN * 2) - help_height - blurb_height)
	juicy_text_y = MARGIN + help_height + (gap / 2)

	text_ang# = 0
	tile_ang# = 0
	
	tile_x# = 0
	tile_y# = 0

	
	; --- Main loop ---

	While Not KeyHit(1)
		frame_start = MilliSecs()

		If KeyHit(59)
			info_on = Not info_on
			slowest_frame = 0
			slowest_fps = 0
		EndIf
		
		If KeyHit(60) Then frame_lock = Not frame_lock
				
		; Draw the animated backround.
		TileBlock star_tile,tile_x,tile_y
		tile_x = tile_x + Cos(tile_ang)
		tile_y = (tile_y + .2) Mod 48.0
		tile_ang = (tile_ang + 1) Mod 360.0
		
		; Animate juicy text by using a sine wave to change the line spacing.
		jf_set_line_spacing(big_font,(Sin(text_ang) * 5))
		text_ang = (text_ang + 10) Mod 360.0

		; Draw animated text.
		jf_text(big_font,400,juicy_text_y,juicy$,1,1,500)
		
		; Draw static text.
		jf_draw_text(help_text)
		jf_draw_text(blurb_text)
		
		frame_time = MilliSecs() - frame_start	
		update_info()

		If frame_lock
			WaitTimer(fps_timer)
			VWait : Flip False
		Else
			Flip False
		EndIf
	Wend

	; Free all fonts.
	jf_free_font(small_font)
	jf_free_font(big_font)
	jf_free_font(debug_font)

	; Free all static text objects.
	jf_free_text(help_text)
	jf_free_text(blurb_text)

	End


;
; Display and/or update info.
;
Function update_info()
	
	If fps_timeout
		frame_count = frame_count + 1

		If MilliSecs() > fps_timeout Then
			fps_timeout = MilliSecs() + 1000 
			fps = frame_count 
			frame_count = 0 
		
			If fps < slowest_fps Or slowest_fps = 0 Then slowest_fps = fps
		EndIf 
		
		If frame_time > slowest_frame Then slowest_frame = frame_time
		
		If info_on
			jf_text(debug_font,10,10,"Millisecs: " + frame_time)
			jf_text(debug_font,10,25,"  Slowest: " + slowest_frame)
			jf_text(debug_font,10,55,"      FPS: " + fps)
			jf_text(debug_font,10,70,"    Worst: " + slowest_fps)
		EndIf
	Else
		; First call initialization.
		fps_timeout = MilliSecs() + 1000 
	EndIf
	
End Function
	
;~IDEal Editor Parameters:
;~C#Blitz3D